Introduction — GramophoneTools 0.7.0-beta documentation

# Introduction

Femtonics Gramophone is a single-dimension locomotion tracking device for mice. With the GramophoneTools Python package you can record locomotion in conjunction with two-photon measurements (see: Recorder module), or train mice in a simple virtual linear maze (see: LinMaze module). For information on how to use the device please refer to the user manual (available as a pdf below).

`Download User Guide (pdf)`

Femtonics Home Page

Product Page

GitHub

# GramophoneTools’ documentation

- Recorder module
  - Main module
  - Logging module
  - Output
- LinMaze module
  - Main module
  - Level
  - Frame
  - Event
  - Rule
  - Zone
  - Output
- Comms module
  - Overview
  - Main module